@@ -95,9 +95,7 @@ def _get_arch():
 @click.option(
     "-c", "--additional_config", help="Base64 encoded configuration like in settings"
 )
-@click.option(
-    "-cR", "--additional_config_raw", help="like ODOO_DEMO=1;RUN_PROXY=0"
-)
+@click.option("-cR", "--additional_config_raw", help="like ODOO_DEMO=1;RUN_PROXY=0")
 @click.option("--images-url", help="default: https://github.com/marcwimmer/odoo")
 @click.option("--no-update-images", is_flag=True)
 @pass_config
@@ -143,10 +141,23 @@ def do_reload(
                 click.secho("\t" + line)
 
         if additional_config_raw:
-            additional_config_raw = '\n'.join(additional_config_raw.split(";"))
-            additional_config = additional_config or ''
+            additional_config_raw = "\n".join(additional_config_raw.split(";"))
+            additional_config = additional_config or ""
             additional_config += "\n" + additional_config_raw
 
+        additional_config = (
+            "\n".join(
+                filter(
+                    lambda x: not x.startswith("#"),
+                    map(lambda x: x.strip(), (additional_config or "").splitlines()),
+                )
+            )
+        ) + "\n"
+        if additional_config:
+            # conflicts with demo flag
+            if "ODOO_DEMO=1\n" in additional_config:
+                demo = True
+
         internal_reload(
             config,
             db,
